@@ -123,9 +123,18 @@ def _close(file):
 def _try_reopen_if_rotated(file, size):
   log('Trying to reopen {0}.', file.name)
   new_size = stat(file.name).st_size
-  if new_size >= size:
+  if new_size == size:
     log('File not rotated.')
     return None
+  if new_size > size:
+    log('File size increased: check rotated')
+    pos = file.tell()
+    file.seek(pos)
+    bytes = file.read(1)
+    if bytes is not None and len(bytes) > 0:
+      log('File not rotated, seek to {0}', pos)
+      file.seek(pos)
+      return None
   log('size={0}, new_size={1}.', size, new_size)
   log('File rotated. reopening.')
   _close(file)
